@@ -2,7 +2,7 @@ import os
 
 import openai
 
-openai.api_key = os.getenv("OPENAI_API_KEY", "")
+openai.api_key = os.getenv("KOPYLOT_AUTH_TOKEN", "")
 
 
 def ask_llm(prompt: str, temperature: float = 0.7, max_tokens: int = 2048) -> str:
